==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TriangulationStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TriangulationStatusEventArgsDescription } from "./TriangulationStatusEventArgsDescription";
/**
 * @hidden
 */
var TriangulationStatusEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TriangulationStatusEventArgsDescriptionMetadata, _super);
    function TriangulationStatusEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TriangulationStatusEventArgsDescriptionMetadata.b = function (a) {
        if (TriangulationStatusEventArgsDescriptionMetadata.a == null) {
            TriangulationStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TriangulationStatusEventArgsDescriptionMetadata.c(TriangulationStatusEventArgsDescriptionMetadata.a);
        }
        if (a.j(TriangulationStatusEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(TriangulationStatusEventArgsDescriptionMetadata.a);
    };
    TriangulationStatusEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentStatus", "Number:int");
    };
    TriangulationStatusEventArgsDescriptionMetadata.d = function (a) {
        TriangulationStatusEventArgsDescriptionMetadata.b(a);
        a.aa("TriangulationStatusEventArgs", function () { return new TriangulationStatusEventArgsDescription(); });
        a.z("TriangulationStatusEventArgs", TriangulationStatusEventArgsDescriptionMetadata.a);
    };
    TriangulationStatusEventArgsDescriptionMetadata.$t = markType(TriangulationStatusEventArgsDescriptionMetadata, 'TriangulationStatusEventArgsDescriptionMetadata');
    TriangulationStatusEventArgsDescriptionMetadata.a = null;
    return TriangulationStatusEventArgsDescriptionMetadata;
}(Base));
export { TriangulationStatusEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/TriangulationStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TriangulationStatusEventArgsDescription } from "./TriangulationStatusEventArgsDescription";
/**
 * @hidden
 */
var TriangulationStatusEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TriangulationStatusEventArgsDescriptionMetadata, _super);
    function TriangulationStatusEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TriangulationStatusEventArgsDescriptionMetadata.b = function (a) {
        if (TriangulationStatusEventArgsDescriptionMetadata.a == null) {
            TriangulationStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TriangulationStatusEventArgsDescriptionMetadata.c(TriangulationStatusEventArgsDescriptionMetadata.a);
        }
        if (a.k(TriangulationStatusEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(TriangulationStatusEventArgsDescriptionMetadata.a);
    };
    TriangulationStatusEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentStatus", "Number:int");
    };
    TriangulationStatusEventArgsDescriptionMetadata.d = function (a) {
        TriangulationStatusEventArgsDescriptionMetadata.b(a);
        a.ac("TriangulationStatusEventArgs", function () { return new TriangulationStatusEventArgsDescription(); });
        a.ab("TriangulationStatusEventArgs", TriangulationStatusEventArgsDescriptionMetadata.a);
    };
    TriangulationStatusEventArgsDescriptionMetadata.$t = markType(TriangulationStatusEventArgsDescriptionMetadata, 'TriangulationStatusEventArgsDescriptionMetadata');
    TriangulationStatusEventArgsDescriptionMetadata.a = null;
    return TriangulationStatusEventArgsDescriptionMetadata;
}(Base));
export { TriangulationStatusEventArgsDescriptionMetadata };
